@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: fast_bbs_handler.cpp 1872 2006-10-22 09:13:10Z svn $
+ * $Id: fast_bbs_handler.cpp 1887 2006-10-22 18:49:12Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -55,7 +55,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: fast_bbs_handler.cpp 1872 2006-10-22 09:13:10Z svn $");
+SOURCE_INFO_ADD("$Id: fast_bbs_handler.cpp 1887 2006-10-22 18:49:12Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -480,7 +480,7 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
     }
 
     if (!can_post(config, Response::get_remote_ip(r))) {
-        THROW(MESSAGE_POST_INTERVAL_TOO_SHORT);
+        return error<Response>(r, config, MESSAGE_POST_INTERVAL_TOO_SHORT);
     }
 
     typename Response::Writer o(r);
@@ -508,6 +508,8 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
         config->get_thread_manager()->add_comment
             (thread_id, name, trip, email, message, time, is_age);
 
+        regist_post(config, Response::get_remote_ip(r));
+
         return redirect<Response>
             (r, o,
              apr_pstrcat
